Module components

Module components 

UI Components

Structs

Button
A Button that can be clicked
Checkbox
A Checkbox can be checked or unchecked
EditText
An EditText allows text input
FrameLayout
A FrameLayout is a simple layout that stacks children on top of each other
GridLayout
A GridLayout arranges children in a grid
HorizontalScrollView
A HorizontalScrollView provides horizontal scrolling for content
ImageView
An ImageView displays images
LinearLayout
A LinearLayout arranges views linearly
NestedScrollView
A NestedScrollView provides scrolling capability
ProgressBar
A ProgressBar displays progress from 0 to 100
RadioButton
A RadioButton in a group
RadioGroup
A RadioGroup manages a set of radio buttons
Space
A Space creates empty space in layouts
Spinner
A Spinner is a dropdown list
SwipeRefreshLayout
A SwipeRefreshLayout provides pull-to-refresh functionality
Switch
A Switch can be toggled on or off
TabLayout
A TabLayout displays a horizontal row of tabs
TextView
A TextView displays text to the user
ToggleButton
A ToggleButton is a button that can be toggled on or off
WebView
WebView component for displaying web content