FrameLayout

Struct FrameLayout 

pub struct FrameLayout { /* private fields */ }
A FrameLayout is a simple layout that stacks children on top of each other

Implementations

Source

impl FrameLayout

pub fn new(activity: &mut Activity, parent: Option<i64>) -> Result<Self>

Create a new FrameLayout

Children are drawn in the order they are added, with the last child on top. FrameLayout is useful for overlaying views or creating simple stacked layouts.

pub fn id(&self) -> i64

Get the view ID

pub fn view(&self) -> &View

Get the underlying View