pub struct ToggleButton { /* private fields */ }Expand description
A ToggleButton is a button that can be toggled on or off
Similar to Switch, but with a different visual style (button appearance).
Implementations
Sourceimpl ToggleButton
impl ToggleButton
Sourcepub fn new(
activity: &mut Activity,
text: &str,
parent: Option<i64>,
) -> Result<Self>
pub fn new( activity: &mut Activity, text: &str, parent: Option<i64>, ) -> Result<Self>
Create a new ToggleButton (unchecked by default)
Sourcepub fn new_with_checked(
activity: &mut Activity,
text: &str,
parent: Option<i64>,
checked: bool,
) -> Result<Self>
pub fn new_with_checked( activity: &mut Activity, text: &str, parent: Option<i64>, checked: bool, ) -> Result<Self>
Create a new ToggleButton with specified checked state